@@ -41,7 +41,7 @@
  *
  */
 
-/* $Id: config.h,v 1.38 2000/01/13 12:12:59 karls Exp $ */
+/* $Id: config.h,v 1.41 2000/10/04 08:13:43 michaels Exp $ */
 
 #ifndef _CONFIG_H_
 #define _CONFIG_H_
@@ -86,6 +86,13 @@
 #define SOCKS_CONFIGFILE			HAVE_ALT_SOCKS_CONFIGFILE
 #endif /* !HAVE_SOCKS_CONFIGFILE */
 
+/*
+ * if we mark a route/socksserver as bad, how many seconds to wait
+ * until we expire the badmarking so it will be tried again for new 
+ * connections.
+ * A value of zero means never.
+*/
+#define BADROUTE_EXPIRE				(60 * 0)
 
 	/*
 	 * server stuff.
@@ -128,8 +135,13 @@
 #define SOCKD_CONFIGFILE			HAVE_ALT_SOCKD_CONFIGFILE
 #endif /* !HAVE_SOCKD_CONFIGFILE */
 
-/* max number of clients pending to server (argument to listen()). */
-#define SOCKD_MAXCLIENTQUE			5
+/* max number of clients pending to server (argument to listen()).
+ * The Apache people say: 
+ *   It defaults to 511 instead of 512 because some systems store it
+ *   as an 8-bit datatype; 512 truncated to 8-bits is 0, while 511 is
+ *   255 when truncated.
+*/
+#define SOCKD_MAXCLIENTQUE			511
 
 
 /*
