@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999
+ * Copyright (c) 1997, 1998, 1999, 2000
  *      Inferno Nettverk A/S, Norway.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,7 +44,7 @@
 #include "common.h"
 
 static const char rcsid[] =
-"$Id: sockd_negotiate.c,v 1.65 1999/12/22 09:29:26 karls Exp $";
+"$Id: sockd_negotiate.c,v 1.70 2000/04/09 10:14:46 karls Exp $";
 
 __BEGIN_DECLS
 
@@ -190,6 +190,14 @@ run_negotiate(mother)
 		struct sockd_negotiate_t *neg;
 		struct timeval timeout;
 
+		while ((neg = neg_gettimedout()) != NULL) {
+			const char *reason = "negotiation timed out";
+
+			iolog(&neg->rule, &neg->state, OPERATION_ABORT, &neg->src,
+			&neg->state.auth, &neg->dst, NULL, reason, strlen(reason));
+			delete_negotiate(mother, neg);
+		}
+
 		fdbits = neg_fillset(&rset);
 		FD_SET(mother->s, &rset);
 		fdbits = MAX(fdbits, mother->s);
@@ -207,19 +215,8 @@ run_negotiate(mother)
 				SERR(-1);
 				/* NOTREACHED */
 
-			case 0: {
-				const char *reason = "negotiation timed out";
-
-				if ((neg = neg_gettimedout()) == NULL)
-					continue; /* should only be possible if sighup received. */
-
-				iolog(&neg->rule, &neg->state, OPERATION_ABORT, &neg->src,
-				&neg->dst, reason, strlen(reason));
-
-				delete_negotiate(mother, neg);
-
+			case 0:
 				continue;
-			}
 		}
 
 		if (FD_ISSET(mother->s, &rset)) {
@@ -259,7 +256,7 @@ run_negotiate(mother)
 				}
 
 				iolog(&neg->rule, &neg->state, OPERATION_ABORT, &neg->src,
-				&neg->dst, reason, strlen(reason));
+				&neg->state.auth, &neg->dst, NULL, reason, strlen(reason));
 
 				delete_negotiate(mother, neg);
 			}
@@ -422,6 +419,7 @@ recv_negotiate(mother)
 	}
 	sockaddr2sockshost(&addr, &neg->dst);
 
+	/* init state correctly for checking a connection to us. */
 	neg->state.command		= SOCKS_ACCEPT;
 	neg->state.protocol		= SOCKS_TCP;
 	neg->state.version		= SOCKS_V5; /* anything valid. */
@@ -431,8 +429,8 @@ recv_negotiate(mother)
 
 	permit = rulespermit(neg->s, &neg->rule, &neg->state, &neg->src, &neg->dst);
 
-	iolog(&neg->rule, &neg->state, OPERATION_ACCEPT, &neg->src, &neg->dst,
-	NULL, 0);
+	iolog(&neg->rule, &neg->state, OPERATION_ACCEPT, &neg->src, &neg->state.auth,
+	&neg->dst, NULL, NULL, 0);
 
 	neg->allocated = 1;
 
@@ -464,7 +462,7 @@ delete_negotiate(mother, neg)
 	*neg = neginit;
 
 	/* ack we have freed a slot. */
-	if (writen(mother->ack, &command, sizeof(command)) != sizeof(command))
+	if (writen(mother->ack, &command, sizeof(command), NULL) != sizeof(command))
 		swarn("%s: writen()", function);
 
 	proctitleupdate();
